Class: Google::Apis::CloudshellV1::StartEnvironmentResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudshell_v1/classes.rb,
lib/google/apis/cloudshell_v1/representations.rb,
lib/google/apis/cloudshell_v1/representations.rb

Overview

Message included in the response field of operations returned from StartEnvironment once the operation is complete.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartEnvironmentResponse

Returns a new instance of StartEnvironmentResponse.



502
503
504
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentGoogle::Apis::CloudshellV1::Environment

A Cloud Shell environment, which is defined as the combination of a Docker image specifying what is installed on the environment and a home directory containing the user's data that will remain across sessions. Each user has at least an environment with the ID "default". Corresponds to the JSON property environment



500
501
502
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 500

def environment
  @environment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



507
508
509
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 507

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
end