Class: Google::Apis::CloudshellV1::CloudShellService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudshellV1::CloudShellService
- Defined in:
- lib/google/apis/cloudshell_v1/service.rb
Overview
Cloud Shell API
Allows users to start, configure, and connect to interactive shell sessions running in the cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudshell.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#add_environment_public_key(environment, add_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Adds a public SSH key to an environment, allowing clients with the corresponding private key to connect to that environment via SSH.
-
#authorize_environment(name, authorize_environment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Sends OAuth credentials to a running environment on behalf of a user.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Empty
Deletes a long-running operation.
-
#generate_user_environment_access_token(environment, expire_time: nil, ttl: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::GenerateAccessTokenResponse
Generates an access token for the user's environment.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Gets the latest state of a long-running operation.
-
#get_user_environment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Environment
Gets an environment.
-
#initialize ⇒ CloudShellService
constructor
A new instance of CloudShellService.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#remove_environment_public_key(environment, remove_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Removes a public SSH key from an environment.
-
#start_environment(name, start_environment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Starts an existing environment, allowing clients to connect to it.
Constructor Details
#initialize ⇒ CloudShellService
Returns a new instance of CloudShellService.
48 49 50 51 52 53 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudshell_v1', client_version: Google::Apis::CloudshellV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#add_environment_public_key(environment, add_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Adds a public SSH key to an environment, allowing clients with the corresponding private key to connect to that environment via SSH. If a key with the same content already exists, this will error with ALREADY_EXISTS.
231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 231 def add_environment_public_key(environment, add_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+environment}:addPublicKey', ) command.request_representation = Google::Apis::CloudshellV1::AddPublicKeyRequest::Representation command.request_object = add_public_key_request_object command.response_representation = Google::Apis::CloudshellV1::Operation::Representation command.response_class = Google::Apis::CloudshellV1::Operation command.params['environment'] = environment unless environment.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#authorize_environment(name, authorize_environment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Sends OAuth credentials to a running environment on behalf of a user. When this completes, the environment will be authorized to run various Google Cloud command line tools without requiring the user to manually authenticate.
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 267 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:authorize', ) command.request_representation = Google::Apis::CloudshellV1::AuthorizeEnvironmentRequest::Representation command.request_object = command.response_representation = Google::Apis::CloudshellV1::Operation::Representation command.response_class = Google::Apis::CloudshellV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 83 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::CloudshellV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::CloudshellV1::Empty::Representation command.response_class = Google::Apis::CloudshellV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
118 119 120 121 122 123 124 125 126 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 118 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudshellV1::Empty::Representation command.response_class = Google::Apis::CloudshellV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_user_environment_access_token(environment, expire_time: nil, ttl: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::GenerateAccessTokenResponse
Generates an access token for the user's environment.
307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 307 def generate_user_environment_access_token(environment, expire_time: nil, ttl: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+environment}:generateAccessToken', ) command.response_representation = Google::Apis::CloudshellV1::GenerateAccessTokenResponse::Representation command.response_class = Google::Apis::CloudshellV1::GenerateAccessTokenResponse command.params['environment'] = environment unless environment.nil? command.query['expireTime'] = expire_time unless expire_time.nil? command.query['ttl'] = ttl unless ttl.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 149 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudshellV1::Operation::Representation command.response_class = Google::Apis::CloudshellV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_environment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Environment
Gets an environment. Returns NOT_FOUND if the environment does not exist.
340 341 342 343 344 345 346 347 348 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 340 def get_user_environment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudshellV1::Environment::Representation command.response_class = Google::Apis::CloudshellV1::Environment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 194 def list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudshellV1::ListOperationsResponse::Representation command.response_class = Google::Apis::CloudshellV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_environment_public_key(environment, remove_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Removes a public SSH key from an environment. Clients will no longer be able to connect to the environment using the corresponding private key. If a key with the same content is not present, this will error with NOT_FOUND.
374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 374 def remove_environment_public_key(environment, remove_public_key_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+environment}:removePublicKey', ) command.request_representation = Google::Apis::CloudshellV1::RemovePublicKeyRequest::Representation command.request_object = remove_public_key_request_object command.response_representation = Google::Apis::CloudshellV1::Operation::Representation command.response_class = Google::Apis::CloudshellV1::Operation command.params['environment'] = environment unless environment.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_environment(name, start_environment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudshellV1::Operation
Starts an existing environment, allowing clients to connect to it. The returned operation will contain an instance of StartEnvironmentMetadata in its metadata field. Users can wait for the environment to start by polling this operation via GetOperation. Once the environment has finished starting and is ready to accept connections, the operation will contain a StartEnvironmentResponse in its response field.
413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/google/apis/cloudshell_v1/service.rb', line 413 def start_environment(name, start_environment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:start', ) command.request_representation = Google::Apis::CloudshellV1::StartEnvironmentRequest::Representation command.request_object = start_environment_request_object command.response_representation = Google::Apis::CloudshellV1::Operation::Representation command.response_class = Google::Apis::CloudshellV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |