Class: Google::Apis::CloudshellV1::StartEnvironmentRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudshellV1::StartEnvironmentRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudshell_v1/classes.rb,
lib/google/apis/cloudshell_v1/representations.rb,
lib/google/apis/cloudshell_v1/representations.rb
Overview
Request message for StartEnvironment.
Instance Attribute Summary collapse
-
#access_token ⇒ String
The initial access token passed to the environment.
-
#public_keys ⇒ Array<String>
Public keys that should be added to the environment before it is started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartEnvironmentRequest
constructor
A new instance of StartEnvironmentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartEnvironmentRequest
Returns a new instance of StartEnvironmentRequest.
478 479 480 |
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_token ⇒ String
The initial access token passed to the environment. If this is present and
valid, the environment will be pre-authenticated with gcloud so that the user
can run gcloud commands in Cloud Shell without having to log in. This code can
be updated later by calling AuthorizeEnvironment.
Corresponds to the JSON property accessToken
471 472 473 |
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 471 def access_token @access_token end |
#public_keys ⇒ Array<String>
Public keys that should be added to the environment before it is started.
Corresponds to the JSON property publicKeys
476 477 478 |
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 476 def public_keys @public_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
483 484 485 486 |
# File 'lib/google/apis/cloudshell_v1/classes.rb', line 483 def update!(**args) @access_token = args[:access_token] if args.key?(:access_token) @public_keys = args[:public_keys] if args.key?(:public_keys) end |